@@ -1,10 +1,10 @@
 <?php
 /**
- * $Horde: imp/attachment.php,v 2.5.10.20 2007/12/18 04:21:42 slusarz Exp $
+ * $Horde: imp/attachment.php,v 2.5.10.22 2008/10/23 16:10:11 slusarz Exp $
  *
  * Copyright 2004-2007 Andrew Coleman <mercury@appisolutions.net>
  *
- * See the enclosed file COPYING for license information (GPL).  If you
+ * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
  *
  * This file should be the basis for serving hosted attachments.  It
@@ -22,8 +22,9 @@ if (!defined('HORDE_BASE')) {
 }
 @define('IMP_BASE', dirname(__FILE__));
 require_once HORDE_BASE . '/lib/core.php';
-require_once 'VFS.php';
+require_once IMP_BASE . '/lib/Compose.php';
 require_once 'Horde/MIME/Magic.php';
+require_once 'VFS.php';
 $registry = &Registry::singleton();
 $registry->importConfig('imp');
 
@@ -54,9 +55,9 @@ if (is_a($vfsroot, 'PEAR_Error')) {
 $mail_user = basename($mail_user);
 $time_stamp = basename($time_stamp);
 $file_name = escapeshellcmd(basename($file_name));
-$full_path = sprintf('.horde/imp/attachments/%s/%d', $mail_user, $time_stamp);
+$full_path = sprintf(IMP_VFS_LINK_ATTACH_PATH . '/%s/%d', $mail_user, $time_stamp);
 if (!$vfsroot->exists($full_path, $file_name)) {
-    Horde::fatal(_("The specified file does not exist."), $_self_url, __LINE__);
+    Horde::fatal(_("The specified attachment does not exist. It may have been deleted by the original sender."), $_self_url, __LINE__);
 }
 
 // Check to see if we need to send a verification message.
@@ -80,18 +81,19 @@ if ($conf['compose']['link_attachments_notify']) {
             Horde::logMessage($res, __FILE__, __LINE__, PEAR_LOG_ERR);
         } else {
             /* Load $mail_user's preferences so that we can use their
-             * locale for the notification message. */
+             * locale information for the notification message. */
             include_once 'Horde/Prefs.php';
-            $mail_prefs = &Prefs::singleton($conf['prefs']['driver'],
-                                            'horde', $mail_user);
-            $mail_prefs->retrieve();
+            $prefs = &Prefs::singleton($conf['prefs']['driver'],
+                                       'horde', $mail_user);
+            $prefs->retrieve();
             include_once 'Horde/Identity.php';
             $mail_identity = &Identity::singleton('none', $mail_user);
             $mail_address = $mail_identity->getDefaultFromAddress();
             /* Ignore missing addresses, which are returned as <>. */
             if (strlen($mail_address) > 2) {
                 $mail_address_full = $mail_identity->getDefaultFromAddress(true);
-                NLS::setLang($mail_prefs->getValue('language'));
+                NLS::setTimeZone();
+                NLS::setLang($prefs->getValue('language'));
                 NLS::setTextdomain('imp', IMP_BASE . '/locale', NLS::getCharset());
                 String::setDefaultCharset(NLS::getCharset());
 
@@ -131,6 +133,13 @@ if ($mime_type === false) {
     $mime_type = MIME_Magic::filenameToMIME($file_name, false);
 }
 
+// Prevent 'jar:' attacks on Firefox.  See Ticket #5892.
+if ($browser->isBrowser('mozilla')) {
+    if (in_array(String::lower($mime_type), array('application/java-archive', 'application/x-jar'))) {
+        $mime_type = 'application/octet-stream';
+    }
+}
+
 // Send the client the file.
 $browser->downloadHeaders($file_name, $mime_type, false, strlen($file_data));
 echo $file_data;
