@@ -7,17 +7,15 @@ require_once 'Horde/Identity.php';
  * user might have. Its methods take care of any site-specific
  * restrictions configured in prefs.php and conf.php.
  *
- * $Horde: imp/lib/Identity/imp.php,v 1.44.2.11.2.1 2007/12/21 00:50:56 jan Exp $
+ * $Horde: imp/lib/Identity/imp.php,v 1.44.2.22 2009/01/06 15:24:08 jan Exp $
  *
- * Copyright 2001-2007 Jan Schneider <jan@horde.org>
- * Copyright 2001-2007 Chuck Hagenbuch <chuck@horde.org>
+ * Copyright 2001-2009 The Horde Project (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
  *
  * @author  Jan Schneider <jan@horde.org>
  * @author  Chuck Hagenbuch <chuck@horde.org>
- * @since   IMP 2.3.7
  * @package Horde_Identity
  */
 class Identity_imp extends Identity {
@@ -60,8 +58,8 @@ class Identity_imp extends Identity {
         $this->_properties = array_merge(
             $this->_properties,
             array('replyto_addr', 'alias_addr', 'tieto_addr', 'bcc_addr',
-                  'mail_hdr', 'signature', 'sig_first', 'sig_dashes',
-                  'save_sent_mail', 'sent_mail_folder'));
+                  'signature', 'sig_first', 'sig_dashes', 'save_sent_mail',
+                  'sent_mail_folder'));
     }
 
     /**
@@ -82,6 +80,23 @@ class Identity_imp extends Identity {
             $identity = $this->_default;
         }
 
+        /* Prepare email validator */
+        require_once 'Horde/Form.php';
+        require_once 'Horde/Variables.php';
+        $email = new Horde_Form_Type_email();
+        $vars = new Variables();
+        $var = new Horde_Form_Variable('', 'replyto_addr', $email, false);
+
+        /* Verify From address. */
+        if (!$email->isValid($var, $vars, $this->getValue('from_addr', $identity), $error_message)) {
+            return PEAR::raiseError($error_message);
+        }
+
+        /* Verify Reply-to address. */
+        if (!$email->isValid($var, $vars, $this->getValue('replyto_addr', $identity), $error_message)) {
+            return PEAR::raiseError($error_message);
+        }
+
         /* Clean up Alias, Tie-to, and BCC addresses. */
         require_once 'Horde/Array.php';
         foreach (array('alias_addr', 'tieto_addr', 'bcc_addr') as $val) {
@@ -91,28 +106,22 @@ class Identity_imp extends Identity {
             }
             $data = trim($data);
             $data = (empty($data)) ? array() : Horde_Array::prepareAddressList(preg_split("/[\n\r]+/", $data));
+
+            /* Validate addresses */
+            foreach ($data as $address) {
+                if (!$email->isValid($var, $vars, $address, $error_message)) {
+                    return PEAR::raiseError($error_message);
+                }
+            }
+
             $this->setValue($val, $data, $identity);
         }
 
-        /* Split the list of headers by new lines and sort the list of headers
-         * to make sure there are no duplicates. */
-        $mail_hdr = $this->getValue('mail_hdr', $identity);
-        if (is_array($mail_hdr)) {
-            $mail_hdr = implode("\n", $mail_hdr);
-        }
-        $mail_hdr = trim($mail_hdr);
-        if (!empty($mail_hdr)) {
-            $mail_hdr = str_replace(':', '', $mail_hdr);
-            $mail_hdr = preg_split("/[\n\r]+/", $mail_hdr);
-            $mail_hdr = array_map('trim', $mail_hdr);
-            $mail_hdr = array_unique($mail_hdr);
-            natcasesort($mail_hdr);
-        }
-        $this->setValue('mail_hdr', $mail_hdr, $identity);
+        return true;
     }
 
     /**
-     * Returns a complete From: header based on all relevent factors (fullname,
+     * Returns a complete From: header based on all relevant factors (fullname,
      * from address, input fields, locks etc.)
      *
      * @param integer $ident        The identity to retrieve the values from.
@@ -125,7 +134,6 @@ class Identity_imp extends Identity {
      */
     function getFromLine($ident = null, $from_address = '')
     {
-        global $imp;
         static $froms = array();
 
         if (isset($froms[$ident])) {
@@ -142,7 +150,11 @@ class Identity_imp extends Identity {
         }
 
         if (!empty($address)) {
-            $ob = imap_rfc822_parse_adrlist($address, $imp['maildomain']);
+            $ob = IMP::parseAddressList($address, false, true);
+        }
+        if (is_a($ob, 'PEAR_Error')) {
+            $ob->message .= ' ' . _("Your From address is not a valid email address. This can be fixed in your Personal Information options page.");
+            return $ob;
         }
 
         if (empty($name)) {
@@ -166,7 +178,7 @@ class Identity_imp extends Identity {
      */
     function getAllFromLines()
     {
-        foreach ($this->_identities as $ident => $dummy) {
+        foreach (array_keys($this->_identities) as $ident) {
             $list[$ident] = $this->getFromAddress($ident);
         }
         return $list;
@@ -218,19 +230,17 @@ class Identity_imp extends Identity {
      */
     function getFromAddress($ident = null)
     {
-        global $imp;
-
         if (!empty($this->_fromList[$ident])) {
             return $this->_fromList[$ident];
         }
 
         $val = $this->getValue('from_addr', $ident);
         if (empty($val)) {
-            $val = $imp['user'];
+            $val = $_SESSION['imp']['user'];
         }
 
         if (!strstr($val, '@')) {
-            $val .= '@' . $imp['maildomain'];
+            $val .= '@' . $_SESSION['imp']['maildomain'];
         }
 
         $this->_fromList[$ident] = $val;
@@ -268,22 +278,16 @@ class Identity_imp extends Identity {
     {
         $list = array();
 
-        foreach ($this->_identities as $key => $identity) {
+        foreach ($this->_identitiesWithDefaultLast() as $key => $identity) {
             /* Get From Addresses. */
-            $addr = String::lower($this->getFromAddress($key));
-            if (!isset($list[$addr])) {
-                $list[$addr] = $key;
-            }
+            $list[String::lower($this->getFromAddress($key))] = $key;
 
             /* Get Aliases. */
             if ($alias) {
                 $addrs = $this->getAliasAddress($key);
                 if (!empty($addrs)) {
-                    foreach ($addrs as $val) {
-                        $val = String::lower($val);
-                        if (!empty($val) && !isset($list[$val])) {
-                            $list[$val] = $key;
-                        }
+                    foreach (array_filter($addrs) as $val) {
+                        $list[String::lower($val)] = $key;
                     }
                 }
             }
@@ -303,13 +307,11 @@ class Identity_imp extends Identity {
     {
         $list = array();
 
-        foreach ($this->_identities as $key => $identity) {
+        foreach ($this->_identitiesWithDefaultLast() as $key => $identity) {
             $tieaddr = $this->getValue('tieto_addr', $key);
             if (!empty($tieaddr)) {
                 foreach ($tieaddr as $val) {
-                    if (!isset($list[$val])) {
-                        $list[$val] = $key;
-                    }
+                    $list[$val] = $key;
                 }
             }
         }
@@ -317,6 +319,24 @@ class Identity_imp extends Identity {
         return $list;
     }
 
+    /**
+     * Returns the list of identities with the default identity positioned
+     * last.
+     *
+     * @access private
+     *
+     * @return array  The identities list with the default identity last.
+     */
+    function _identitiesWithDefaultLast()
+    {
+        $ids = $this->_identities;
+        $default = $this->getDefault();
+        $tmp = $ids[$default];
+        unset($ids[$default]);
+        $ids[$default] = $tmp;
+        return $ids;
+    }
+
     /**
      * Returns the BCC addresses for a given identity.
      *
@@ -333,8 +353,11 @@ class Identity_imp extends Identity {
             if (!is_array($bcc)) {
                 $bcc = array($bcc);
             }
-            $addresses = implode(', ', $bcc);
-            return imap_rfc822_parse_adrlist($addresses, '');
+            $addr_list = IMP::parseAddressList(implode(', ', $bcc));
+            if (is_a($addr_list, 'PEAR_Error')) {
+                return array();
+            }
+            return $addr_list;
         }
     }
 
@@ -360,13 +383,18 @@ class Identity_imp extends Identity {
         }
 
         /* Normalize address list. */
-        if (!is_array($addresses)) {
+        if (is_array($addresses)) {
+            $addresses = array_filter($addresses);
+        } else {
             $addresses = array($addresses);
         }
-        $addresses = implode(', ', $addresses);
-        $addresses = imap_rfc822_parse_adrlist($addresses, '');
 
-        foreach ($addresses as $address) {
+        $addr_list = IMP::parseAddressList(implode(', ', $addresses));
+        if (is_a($addr_list, 'PEAR_Error')) {
+            return null;
+        }
+
+        foreach ($addr_list as $address) {
             if (empty($address->mailbox)) {
                 continue;
             }
@@ -447,10 +475,8 @@ class Identity_imp extends Identity {
         }
 
         if (!empty($GLOBALS['conf']['hooks']['signature'])) {
-            include_once HORDE_BASE . '/config/hooks.php';
-            if (function_exists('_imp_hook_signature')) {
-                $val = call_user_func('_imp_hook_signature', $val);
-            }
+            $val = Horde::callHook('_imp_hook_signature', array($val),
+                                   'imp', $val);
         }
 
         $this->_signatures[$ident] = $val;
@@ -501,10 +527,12 @@ class Identity_imp extends Identity {
         $list = array();
         foreach ($this->_identities as $key => $identity) {
             if ($folder = $this->getValue('sent_mail_folder', $key)) {
-                $list[$folder] = true;
+                $list[$folder] = 1;
             }
         }
-        return array_keys($list);
+
+        /* Get rid of duplicates and empty folders. */
+        return array_filter(array_keys($list));
     }
 
     /**
